@@ -57,6 +57,58 @@ pango_underline_get_type (void)
   return etype;
 }
 
+/* enumerations from "pango-bidi-type.h" */
+GType
+pango_bidi_type_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { PANGO_BIDI_TYPE_L, "PANGO_BIDI_TYPE_L", "l" },
+      { PANGO_BIDI_TYPE_LRE, "PANGO_BIDI_TYPE_LRE", "lre" },
+      { PANGO_BIDI_TYPE_LRO, "PANGO_BIDI_TYPE_LRO", "lro" },
+      { PANGO_BIDI_TYPE_R, "PANGO_BIDI_TYPE_R", "r" },
+      { PANGO_BIDI_TYPE_AL, "PANGO_BIDI_TYPE_AL", "al" },
+      { PANGO_BIDI_TYPE_RLE, "PANGO_BIDI_TYPE_RLE", "rle" },
+      { PANGO_BIDI_TYPE_RLO, "PANGO_BIDI_TYPE_RLO", "rlo" },
+      { PANGO_BIDI_TYPE_PDF, "PANGO_BIDI_TYPE_PDF", "pdf" },
+      { PANGO_BIDI_TYPE_EN, "PANGO_BIDI_TYPE_EN", "en" },
+      { PANGO_BIDI_TYPE_ES, "PANGO_BIDI_TYPE_ES", "es" },
+      { PANGO_BIDI_TYPE_ET, "PANGO_BIDI_TYPE_ET", "et" },
+      { PANGO_BIDI_TYPE_AN, "PANGO_BIDI_TYPE_AN", "an" },
+      { PANGO_BIDI_TYPE_CS, "PANGO_BIDI_TYPE_CS", "cs" },
+      { PANGO_BIDI_TYPE_NSM, "PANGO_BIDI_TYPE_NSM", "nsm" },
+      { PANGO_BIDI_TYPE_BN, "PANGO_BIDI_TYPE_BN", "bn" },
+      { PANGO_BIDI_TYPE_B, "PANGO_BIDI_TYPE_B", "b" },
+      { PANGO_BIDI_TYPE_S, "PANGO_BIDI_TYPE_S", "s" },
+      { PANGO_BIDI_TYPE_WS, "PANGO_BIDI_TYPE_WS", "ws" },
+      { PANGO_BIDI_TYPE_ON, "PANGO_BIDI_TYPE_ON", "on" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static (g_intern_static_string ("PangoBidiType"), values);
+  }
+  return etype;
+}
+GType
+pango_direction_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { PANGO_DIRECTION_LTR, "PANGO_DIRECTION_LTR", "ltr" },
+      { PANGO_DIRECTION_RTL, "PANGO_DIRECTION_RTL", "rtl" },
+      { PANGO_DIRECTION_TTB_LTR, "PANGO_DIRECTION_TTB_LTR", "ttb-ltr" },
+      { PANGO_DIRECTION_TTB_RTL, "PANGO_DIRECTION_TTB_RTL", "ttb-rtl" },
+      { PANGO_DIRECTION_WEAK_LTR, "PANGO_DIRECTION_WEAK_LTR", "weak-ltr" },
+      { PANGO_DIRECTION_WEAK_RTL, "PANGO_DIRECTION_WEAK_RTL", "weak-rtl" },
+      { PANGO_DIRECTION_NEUTRAL, "PANGO_DIRECTION_NEUTRAL", "neutral" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static (g_intern_static_string ("PangoDirection"), values);
+  }
+  return etype;
+}
+
 /* enumerations from "pango-coverage.h" */
 GType
 pango_coverage_level_get_type (void)
@@ -340,6 +392,17 @@ pango_script_get_type (void)
       { PANGO_SCRIPT_PHOENICIAN, "PANGO_SCRIPT_PHOENICIAN", "phoenician" },
       { PANGO_SCRIPT_PHAGS_PA, "PANGO_SCRIPT_PHAGS_PA", "phags-pa" },
       { PANGO_SCRIPT_NKO, "PANGO_SCRIPT_NKO", "nko" },
+      { PANGO_SCRIPT_KAYAH_LI, "PANGO_SCRIPT_KAYAH_LI", "kayah-li" },
+      { PANGO_SCRIPT_LEPCHA, "PANGO_SCRIPT_LEPCHA", "lepcha" },
+      { PANGO_SCRIPT_REJANG, "PANGO_SCRIPT_REJANG", "rejang" },
+      { PANGO_SCRIPT_SUNDANESE, "PANGO_SCRIPT_SUNDANESE", "sundanese" },
+      { PANGO_SCRIPT_SAURASHTRA, "PANGO_SCRIPT_SAURASHTRA", "saurashtra" },
+      { PANGO_SCRIPT_CHAM, "PANGO_SCRIPT_CHAM", "cham" },
+      { PANGO_SCRIPT_OL_CHIKI, "PANGO_SCRIPT_OL_CHIKI", "ol-chiki" },
+      { PANGO_SCRIPT_VAI, "PANGO_SCRIPT_VAI", "vai" },
+      { PANGO_SCRIPT_CARIAN, "PANGO_SCRIPT_CARIAN", "carian" },
+      { PANGO_SCRIPT_LYCIAN, "PANGO_SCRIPT_LYCIAN", "lycian" },
+      { PANGO_SCRIPT_LYDIAN, "PANGO_SCRIPT_LYDIAN", "lydian" },
       { 0, NULL, NULL }
     };
     etype = g_enum_register_static (g_intern_static_string ("PangoScript"), values);
@@ -362,26 +425,5 @@ pango_tab_align_get_type (void)
   return etype;
 }
 
-/* enumerations from "pango-types.h" */
-GType
-pango_direction_get_type (void)
-{
-  static GType etype = 0;
-  if (etype == 0) {
-    static const GEnumValue values[] = {
-      { PANGO_DIRECTION_LTR, "PANGO_DIRECTION_LTR", "ltr" },
-      { PANGO_DIRECTION_RTL, "PANGO_DIRECTION_RTL", "rtl" },
-      { PANGO_DIRECTION_TTB_LTR, "PANGO_DIRECTION_TTB_LTR", "ttb-ltr" },
-      { PANGO_DIRECTION_TTB_RTL, "PANGO_DIRECTION_TTB_RTL", "ttb-rtl" },
-      { PANGO_DIRECTION_WEAK_LTR, "PANGO_DIRECTION_WEAK_LTR", "weak-ltr" },
-      { PANGO_DIRECTION_WEAK_RTL, "PANGO_DIRECTION_WEAK_RTL", "weak-rtl" },
-      { PANGO_DIRECTION_NEUTRAL, "PANGO_DIRECTION_NEUTRAL", "neutral" },
-      { 0, NULL, NULL }
-    };
-    etype = g_enum_register_static (g_intern_static_string ("PangoDirection"), values);
-  }
-  return etype;
-}
-
 /* Generated data ends here */
 
