@@ -19,7 +19,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
+#include "config.h"
 
 #include "pangocairo.h"
 #include "pangocairo-private.h"
@@ -130,7 +130,7 @@ pango_cairo_font_map_new_for_font_type (cairo_font_type_t fonttype)
   switch (fonttype)
   {
 #if defined(HAVE_CAIRO_ATSUI)
-    case CAIRO_FONT_TYPE_ATSUI:
+    case CAIRO_FONT_TYPE_QUARTZ:
       return g_object_new (PANGO_TYPE_CAIRO_ATSUI_FONT_MAP, NULL);
 #endif
 #if defined(HAVE_CAIRO_WIN32)
@@ -146,6 +146,8 @@ pango_cairo_font_map_new_for_font_type (cairo_font_type_t fonttype)
   }
 }
 
+static PangoFontMap *default_font_map = NULL;
+
 /**
  * pango_cairo_font_map_get_default:
  *
@@ -156,7 +158,12 @@ pango_cairo_font_map_new_for_font_type (cairo_font_type_t fonttype)
  * You generally should only use the #PangoFontMap and
  * #PangoCairoFontMap interfaces on the returned object.
  *
- * Return value: the default Cairo fontmap for #Pango. This
+ * The default Cairo fontmap can be changed by using
+ * pango_cairo_font_map_set_default().  This can be used to
+ * change the Cairo font backend that the default fontmap
+ * uses for example.
+ *
+ * Return value: the default Cairo fontmap for Pango. This
  *  object is owned by Pango and must not be freed.
  *
  * Since: 1.10
@@ -164,14 +171,44 @@ pango_cairo_font_map_new_for_font_type (cairo_font_type_t fonttype)
 PangoFontMap *
 pango_cairo_font_map_get_default (void)
 {
-  static PangoFontMap *default_font_map = NULL;
-
   if (G_UNLIKELY (!default_font_map))
     default_font_map = pango_cairo_font_map_new ();
 
   return default_font_map;
 }
 
+/**
+ * pango_cairo_font_map_set_default:
+ * @fontmap: The new default font map, or %NULL
+ *
+ * Sets a default #PangoCairoFontMap to use with Cairo.
+ *
+ * This can be used to change the Cairo font backend that the
+ * default fontmap uses for example.  The old default font map
+ * is unreffed and the new font map referenced.
+ *
+ * A value of %NULL for @fontmap will cause the current default
+ * font map to be released and a new default font
+ * map to be created on demand, using pango_cairo_font_map_new().
+ *
+ * Since: 1.22
+ **/
+void
+pango_cairo_font_map_set_default (PangoCairoFontMap *fontmap)
+{
+  g_return_if_fail (fontmap == NULL || PANGO_IS_CAIRO_FONT_MAP (fontmap));
+
+  if ((PangoFontMap *) fontmap == default_font_map)
+    return;
+
+  if (default_font_map)
+    g_object_unref (default_font_map);
+
+  if (fontmap)
+    g_object_ref (fontmap);
+  default_font_map = fontmap;
+}
+
 /**
  * pango_cairo_font_map_set_resolution:
  * @fontmap: a #PangoCairoFontMap
@@ -218,6 +255,9 @@ pango_cairo_font_map_get_resolution (PangoCairoFontMap *fontmap)
  *
  * Create a #PangoContext for the given fontmap.
  *
+ * As of Pango 1.20 this function is deprecated.
+ * Use pango_font_map_create_context() instead.
+ *
  * Return value: the newly created context; free with g_object_unref().
  *
  * Since: 1.10
@@ -225,14 +265,9 @@ pango_cairo_font_map_get_resolution (PangoCairoFontMap *fontmap)
 PangoContext *
 pango_cairo_font_map_create_context (PangoCairoFontMap *fontmap)
 {
-  PangoContext *context;
-
   g_return_val_if_fail (PANGO_IS_CAIRO_FONT_MAP (fontmap), NULL);
 
-  context = pango_context_new ();
-  pango_context_set_font_map (context, PANGO_FONT_MAP (fontmap));
-
-  return context;
+  return pango_font_map_create_context (PANGO_FONT_MAP (fontmap));
 }
 
 /**
