@@ -22,7 +22,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
+#include "config.h"
 
 #include <string.h>
 #include <stdlib.h>
@@ -122,17 +122,16 @@ pango_win32_get_hfont (PangoFont *font)
  *
  * Retrieves a #PangoContext appropriate for rendering with Windows fonts.
   *
+ * As of Pango 1.20 this function is deprecated.
+ * Use pango_win32_font_map_for_display() followed by
+ * pango_font_map_create_context() instead.
+ *
  * Return value: the new #PangoContext
  **/
 PangoContext *
 pango_win32_get_context (void)
 {
-  PangoContext *result;
-
-  result = pango_context_new ();
-  pango_context_set_font_map (result, pango_win32_font_map_for_display ());
-
-  return result;
+  return pango_font_map_create_context (pango_win32_font_map_for_display ());
 }
 
 G_DEFINE_TYPE (PangoWin32Font, _pango_win32_font, PANGO_TYPE_FONT)
@@ -586,7 +585,7 @@ pango_win32_font_get_metrics (PangoFont     *font,
 	      PangoLayout *layout;
 
 	      /*  Get the average width of the chars in "0123456789" */
-	      context = pango_win32_get_context ();
+	      context = pango_font_map_create_context (pango_win32_font_map_for_display ());
 	      pango_context_set_language (context, language);
 	      font_desc = pango_font_describe_with_absolute_size (font);
 	      pango_context_set_font_description (context, font_desc);
@@ -1631,8 +1630,8 @@ font_has_name_in (PangoFont                       *font,
       if ((record.name_id != 1 && record.name_id != 16) || record.string_length <= 0)
 	continue;
 
-      PING(("platform:%d encoding:%d language:%04x name_id:%d",
-	    record.platform_id, record.encoding_id, record.language_id, record.name_id));
+      PING (("platform:%d encoding:%d language:%04x name_id:%d",
+	     record.platform_id, record.encoding_id, record.language_id, record.name_id));
 
       if (record.platform_id == MICROSOFT_PLATFORM_ID)
 	if ((cjkv == PANGO_WIN32_COVERAGE_ZH_TW &&
@@ -1709,10 +1708,15 @@ pango_win32_font_calc_coverage (PangoFont     *font,
   guint32 i;
   PangoWin32CoverageLanguageClass cjkv;
   gboolean hide_unihan = FALSE;
+  PangoFontDescription *desc;
+  gchar *name;
 
-  PING(("font:%s lang:%s",
-	pango_font_description_to_string (pango_font_describe (font)),
-	pango_language_to_string (lang)));
+  desc = pango_font_describe (font);
+  name = pango_font_description_to_string (desc);
+  PING (("font:%s lang:%s", name,
+	 pango_language_to_string (lang)));
+  g_free (name);
+  pango_font_description_free (desc);
 
   if (win32font->win32face->has_cmap)
     {
@@ -1732,7 +1736,7 @@ pango_win32_font_calc_coverage (PangoFont     *font,
 
   if (cjkv != PANGO_WIN32_COVERAGE_UNSPEC && !font_has_name_in (font, cjkv))
     {
-      PING(("hiding UniHan chars"));
+      PING (("hiding UniHan chars"));
       hide_unihan = TRUE;
     }
 
